UBI: tweak volumes locking

Transform vtbl_mutex to volumes_mutex - this just makes code
easier to understand.

Signed-off-by: Artem Bityutskiy <Artem.Bityutskiy@nokia.com>
diff --git a/drivers/mtd/ubi/kapi.c b/drivers/mtd/ubi/kapi.c
index c2fafe6..8e15002 100644
--- a/drivers/mtd/ubi/kapi.c
+++ b/drivers/mtd/ubi/kapi.c
@@ -162,15 +162,16 @@
 	desc->mode = mode;
 
 	/*
 	 * To prevent simultaneous checks of the same volume we use @vtbl_mutex,
 	 * although it is not the purpose it was introduced for.
 	 */
-	mutex_lock(&ubi->vtbl_mutex);
+	mutex_lock(&ubi->volumes_mutex);
 	if (!vol->checked) {
 		/* This is the first open - check the volume */
 		err = ubi_check_volume(ubi, vol_id);
 		if (err < 0) {
-			mutex_unlock(&ubi->vtbl_mutex);
+			mutex_unlock(&ubi->volumes_mutex);
 			ubi_close_volume(desc);
 			return ERR_PTR(err);
 		}
@@ -181,7 +182,7 @@
 		}
 		vol->checked = 1;
 	}
-	mutex_unlock(&ubi->vtbl_mutex);
+	mutex_unlock(&ubi->volumes_mutex);
 	return desc;
 
 out_unlock:
@@ -162,15 +162,16 @@
 
 	/*
-	 * To prevent simultaneous checks of the same volume we use @vtbl_mutex,
-	 * although it is not the purpose it was introduced for.
+	 * To prevent simultaneous checks of the same volume we use
+	 * @volumes_mutex, although it is not the purpose it was introduced
+	 * for.
 	 */